@@ -50,20 +50,14 @@ def create_author(ctx: click.Context, author: str) -> None:
 
 def _get_author_notionID(ctx: click.Context, author: str) -> Dict:
     authors = ctx.obj["authors"]
-    extract = process.extractOne(author, authors.keys(), **_extractOne)
-    if not extract:
-        try:
-            create_author(ctx, author)
-        except:
-            print(author)
-            print(asdict(Author(author)))
+    try:
+        # Essentially a no-op, so it sidesteps error-handling
+        create_author(ctx, author)
         extract = process.extractOne(author, authors.keys(), **_extractOne)
-
-    if extract:
-        return {"id": authors[extract[0]]["notionID"]} 
-
-    # Cut our losses to avoid blowing up the Author database.
-    return None
+        return {"id": authors[extract[0]]["notionID"]}
+    except:  # Too many possible errors
+        # Cut our losses to avoid blowing up the Author database.
+        return None
 
 
 def create_article(ctx: click.Context, entry: Dict) -> None:
